@@ -73,6 +73,9 @@ sources <- function(id,
 
 query_sources <- sources
 
+
+
+
 ## Map (closure) to select the sources_* function for the type
 known_sources <- function(type){ 
   switch(type,
@@ -103,9 +106,9 @@ generic_source <- function(id, registries, type){
 ## Map short names into recognized URL endpoints
 expand_registry_urls <- function(registries) {
   registries[grepl("^dataone$", registries)] <- "https://cn.dataone.org"
-  registries[grepl("^hash-archive$", registries)] <- "https://hash-archive.org"
-  registries[grepl("softwareheritage", registries)] <- "https://archive.softwareheritage.org"
-  registries[grepl("zenodo", registries)] <- "https://zenodo.org"
+  registries[grepl("^hash-archive$", registries)] <- "https://hash-archive.carlboettiger.info"
+  registries[grepl("^softwareheritage$", registries)] <- "https://archive.softwareheritage.org"
+  registries[grepl("^zenodo$", registries)] <- "https://zenodo.org"
   registries
 }
 ## Map URLs and paths to corresponding short names
@@ -115,11 +118,17 @@ detect_registry_type <- function(registries) {
   registries[grepl("softwareheritage", registries)] <- "softwareheritage"
   registries[grepl("zenodo", registries)] <- "zenodo"
   registries[is_path_tsv(registries)] <- "tsv"
-  registries[is(registries, "mdb_env")] <- "lmdb"
+  registries[is_lmdb(registries)] <- "lmdb"
   registries[dir.exists(registries)] <- "content_store"
   registries
 }
 
+is_lmdb <- function(registries){
+  by_type <- vapply(registries, inherits, logical(1L), "mdb_env")
+  if(all(is.character(registries)))
+    by_pattern <- grepl("lmdb$", registries)
+  by_type | by_pattern
+}
 
 
 # For a single identifier, some registries (tsv and hash-archive) can contain
@@ -193,20 +202,3 @@ most_recent_sources <- function(df){
   out
 }
 
-
-## Note that this requires computing file size and file modification time
-## needless delay
-sources_store <- function(id, dir = content_dir()){
-  source = content_based_location(id, dir)
-  if(file.exists(source)){
-    info <- fs::file_info(source)
-    registry_entry(id = id, 
-                   source = source, 
-                   date = info$modification_time,
-                   size = info$size
-                   )
-  } else {
-    registry_entry(id = id, status=404)
-  }
-}
-
